@@ -1,17 +1,15 @@
-# $Id: Passthru.pm,v 1.2 2000/05/08 13:10:41 matt Exp $
+# $Id: Passthru.pm,v 1.3 2000/09/10 15:04:29 matt Exp $
 
 package Apache::AxKit::Plugins::Passthru;
 
 use strict;
 use Apache::Constants;
-use CGI ();
+use Apache::Request;
 
 sub handler {
-	my $r = shift;
+	my $r = Apache::Request->new(shift);
 	
-	my $q = CGI->new();
-	
-	my $passthru = $q->param('passthru');
+	my $passthru = $r->param('passthru');
 	if ($passthru) {
 #		warn "Setting passthru\n";
 		$r->notes('axkit_passthru', 1);
