@@ -1,4 +1,4 @@
-# $Id: FileSuffix.pm,v 1.3 2000/05/03 15:46:56 matt Exp $
+# $Id: FileSuffix.pm,v 1.5 2000/06/12 16:51:50 matt Exp $
 
 package Apache::AxKit::StyleChooser::FileSuffix;
 
@@ -6,22 +6,16 @@ use strict;
 use Apache::Constants;
 use Apache::URI;
 
-########
-## This needs fixing, it probably won't work...
-## The XMLFinder will return false, not set the handler to perl-script
-## and so this handler will never get called.
-########
-
 sub handler {
 	my $r = shift;
 	
 	my $file = $r->filename();
-	
-	if ($style && $style =~ s/\.(\w+?)$// && -e $style) {
-		my $type = $1;
-		$r->filename($style);
+	my($style) = ($file =~ m/\.(\w+?)$/);
+
+	if ($style && $file =~ s/\.\w+?$// && -e $file) {
+		$r->filename($file);
 #		warn "setting notes: $style\n";
-		$r->notes('preferred_style', $type);
+		$r->notes('preferred_style', $style);
 	}
 	return DECLINED;
 }
@@ -39,8 +33,9 @@ This module lets you pick a stylesheet based on the filename suffix. To use
 it, simply add this module to the list of PerlTypeHandlers prior to
 Apache::AxKit::XMLFinder:
 
-	PerlTypeHandler Apache::AxKit::StyleChooser::FileSuffix \
-			Apache::AxKit::XMLFinder
+	PerlTypeHandler Apache::AxKit::StyleChooser::FileSuffix
+	SetHandler perl-script
+	PerlHandler AxKit
 
 Then simply by referencing your xml files as follows:
 
@@ -52,7 +47,6 @@ the HTML 4.0 specification for more details on stylesheet choice.
 Note that this installation is different from the other StyleChoosers,
 because the file we're requesting here doesn't actually exist.
 
-(Thanks to Salve J. Nilsen for this module, who I couldn't thank directly
-because his mail came to me From: "sjn@localhost.localdomain")
+Thanks to Salve J. Nilsen <sjn@foo.no> for this module.
 
 =cut
