@@ -1,4 +1,4 @@
-# $Id: PathInfo.pm,v 1.3 2000/05/06 11:12:21 matt Exp $
+# $Id: PathInfo.pm,v 1.4 2000/06/12 16:20:51 matt Exp $
 
 package Apache::AxKit::StyleChooser::PathInfo;
 
@@ -46,7 +46,7 @@ it, simply add this module to the list of PerlHandlers prior to
 Apache::XMLStylesheet:
 
 	PerlHandler Apache::AxKit::StyleChooser::PathInfo \
-			Apache::AxKit::StyleFinder
+			AxKit
 
 Then simply by referencing your xml files as follows:
 
